@@ -1,6 +1,6 @@
 from typing import List, Tuple
 from path import Path
-import ui
+import cli_ui as ui
 
 import tbump.action
 from tbump.config import Config
@@ -28,8 +28,9 @@ class NoTrackedBranch(tbump.git.GitError):
         self.branch = branch
 
     def print_error(self) -> None:
-        ui.error("Current branch (%s)" % self.branch,
-                 "does not track anything. Cannot push.")
+        ui.error(
+            "Current branch (%s)" % self.branch, "does not track anything. Cannot push."
+        )
 
 
 class RefAlreadyExists(tbump.git.GitError):
@@ -59,14 +60,14 @@ class Command(tbump.action.Action):
         return tbump.git.run_git(*full_args, verbose=False)
 
 
-class GitBumper():
+class GitBumper:
     def __init__(self, repo_path: Path):
         self.repo_path = repo_path
         self.tag_template = ""
         self.message_template = ""
         self.remote_name = ""
         self.remote_branch = ""
-        self.commands = list()  # type: List[Command]
+        self.commands = []  # type: List[Command]
 
     def set_config(self, config: Config) -> None:
         self.tag_template = config.tag_template
@@ -100,8 +101,8 @@ class GitBumper():
     def get_tracking_ref(self) -> str:
         branch_name = self.get_current_branch()
         rc, out = self.run_git_captured(
-            "rev-parse", "--abbrev-ref", "--symbolic-full-name", "@{u}",
-            check=False)
+            "rev-parse", "--abbrev-ref", "--symbolic-full-name", "@{u}", check=False
+        )
         if rc != 0:
             raise NoTrackedBranch(branch=branch_name)
         return out
@@ -111,8 +112,7 @@ class GitBumper():
         if rc == 0:
             raise RefAlreadyExists(ref=tag_name)
 
-    def check_state(self, new_version: str) -> None:
-        self.check_dirty()
+    def check_branch_state(self, new_version: str) -> None:
         self.get_current_branch()
         tag_name = self.tag_template.format(new_version=new_version)
         self.check_ref_does_not_exists(tag_name)
@@ -125,7 +125,7 @@ class GitBumper():
         commands.append(command)
 
     def get_commands(self, new_version: str) -> List[Command]:
-        res = list()  # type: List[Command]
+        res = []  # type: List[Command]
         self.add_command(res, "add", "--update")
         commit_message = self.message_template.format(new_version=new_version)
         self.add_command(res, "commit", "--message", commit_message)
