@@ -1,12 +1,11 @@
 from path import Path
-import toml
+import tomlkit
 
 import tbump.config
 import tbump.main
 
 import pytest
-from ui.tests.conftest import message_recorder
-from tbump.test.conftest import file_contains
+from cli_ui.tests import MessageRecorder
 
 
 def test_creates_config(test_repo: Path) -> None:
@@ -17,13 +16,13 @@ def test_creates_config(test_repo: Path) -> None:
     tbump.main.main(["-C", test_repo, "init", current_version])
 
     assert tbump_path.exists()
-    config = toml.loads(tbump_path.text())
+    config = tomlkit.loads(tbump_path.text())
     assert config["version"]["current"] == "1.2.41-alpha1"
-    first_match = config["file"][0]
-    assert file_contains(test_repo / first_match["src"], current_version)
 
 
-def test_abort_if_tbump_toml_exists(test_repo: Path, message_recorder: message_recorder) -> None:
+def test_abort_if_tbump_toml_exists(
+    test_repo: Path, message_recorder: MessageRecorder
+) -> None:
     with pytest.raises(SystemExit):
         tbump.main.main(["-C", test_repo, "init", "1.2.41-alpha1"])
     assert message_recorder.find("already exists")
